# Ample

Ample is a Python package that implements the algorithm described by Hie, Cho, DeDemeo, Bryson, and Berger (2018).

Algorithm implementation is in `bin/sketch.py`.

Examples can be found in `bin/`.